@@ -14,14 +14,14 @@ str_or_bytes = Union[str, bytes]
 class AESCipher(object):
     def __init__(self, key: str_or_bytes) -> None:
         if isinstance(key, str):
-            key = key.encode()
+            key = key.encode("utf-8")
         self.key = hashlib.sha256(key).digest()
 
     def encrypt(self, raw: str_or_bytes) -> str:
         raw = _pad(raw)
         iv = Random.new().read(AES.block_size)
         cipher = AES.new(self.key, AES.MODE_CBC, iv)
-        return base64.b64encode(iv + cipher.encrypt(raw)).decode()
+        return base64.b64encode(iv + cipher.encrypt(raw)).decode("utf-8")
 
     def decrypt(self, enc: str) -> str_or_bytes:
         enc = base64.b64decode(enc)
